@@ -14,13 +14,14 @@ return {
         "zerocount", "minusone", "minustwo",
         "plusone", "plustwo", "plusthree", "plusfour", "plusfive", "plussix", "plusseven", "pluseight",
         "plusnine", "plusten", "pluseleven", "plustwelve", "plusthirteen", "plusfourteen", "plusfifteen", "plussixteen",
-        "plusfifty", "plushundred", "plusonehundred", "plustwohundred", "plusfivehundred",
+        "plusfifty", "plussixty", "plushundred", "plusonehundred", "plustwohundred", "plusfivehundred",
         "plusonehundredtwentyfive", "plustwohundredfifty",
         "plusthousand", "plustenthousand", "plustwentythousand", "medcard", "maxcard", "maxcardminusone", "maxiterator",
         "plusonethousand", "plustwothousand", "plusthreethousand", "plusfourthousand", "plusfivethousand",
         "plussixthousand", "plusseventhousand", "pluseightthousand", "plusninethousand",
         "plusfifteenhundred", "plustwentyfivehundred", "plusfortyfivehundred", "plusseventyfivehundred",
-        "plusninetynine", "plusfourtytwo", "plustwentyfive",
+        "plusninetynine", "plusthirtytwo",  "plusfourtytwo", "plustwentyfour", "plustwentyfive",
+        "plusthousandfifty", "plustwelvehundredfifty",
         "zeropoint", "onepoint", "halfapoint", "onebasepoint", "maxcount", "maxdimen", "scaledpoint", "thousandpoint",
         "points", "halfpoint", "twopoints", "threepoints",
         "zeroskip", "centeringskip", "stretchingskip", "shrinkingskip",
@@ -67,7 +68,7 @@ return {
         "inicatcodes",
         "ctxcatcodes", "texcatcodes", "notcatcodes", "txtcatcodes", "vrbcatcodes",
         "prtcatcodes", "nilcatcodes", "luacatcodes", "tpacatcodes", "tpbcatcodes",
-        "xmlcatcodes", "ctdcatcodes", "rlncatcodes",
+        "xmlcatcodes", "ctdcatcodes", "rlncatcodes", "hshcatcodes",
         --
         "escapecatcode", "begingroupcatcode", "endgroupcatcode", "mathshiftcatcode", "alignmentcatcode",
         "endoflinecatcode", "parametercatcode", "superscriptcatcode", "subscriptcatcode", "ignorecatcode",
@@ -92,7 +93,7 @@ return {
         "demeritsfrozenparcode", "shapefrozenparcode", "linefrozenparcode", "hyphenationfrozenparcode",
         "shapingpenaltyfrozenparcode", "orphanpenaltyfrozenparcode", "toddlerpenaltyfrozenparcode",
         "emergencyfrozenparcode", "parpassesfrozenparcode", "singlelinepenaltyfrozenparcode",
-        "hyphenpenaltyfrozenparcode", "exhyphenpenaltyfrozenparcode", "linebreakchecksfrozenparcode",
+        "hyphenpenaltyfrozenparcode", "linesnappingfrozenparcode", "linebreakchecksfrozenparcode",
         "twindemeritsfrozenparcode", "fitnessclassesfrozenparcode", "allfrozenparcode",
         --
         "activemathcharcode",
@@ -160,6 +161,10 @@ return {
         "mathaxisheight",
         "muquad",
         --
+        "smallcapsratio",
+        "currentspaceskip", "currentspacevalue", "usedspacevalue",
+        "mathstacktotal", "mathstackvgap",
+        --
         -- maybe a different class
         --
         "startmode", "stopmode", "startnotmode", "stopnotmode", "startmodeset", "stopmodeset",
@@ -176,9 +181,13 @@ return {
         "doifelsedocumentvariable", "doifdocumentvariableelse", "doifdocumentvariable", "doifnotdocumentvariable",
         "startmodule", "stopmodule", "usemodule", "usetexmodule", "useluamodule","setupmodule","currentmoduleparameter","moduleparameter",
         "everystarttext", "everystoptext", "everyforgetall", "luaenvironment",
+        --
+        -- -- maybe do all the important every's
+        --
+     -- "everymathematics", "everyinsidemathematics",
         --
         "startTEXpage", "stopTEXpage",
-    --  "startMPpage", "stopMPpage", -- already catched by nested lexer
+     -- "startMPpage", "stopMPpage", -- already catched by nested lexer
         --
         "enablemode", "disablemode", "preventmode", "definemode",
         "globalenablemode", "globaldisablemode", "globalpreventmode",
@@ -227,7 +236,7 @@ return {
         --
         "startlmtxmode", "stoplmtxmode", "startmkivmode", "stopmkivmode",
         --
-        "wildcardsymbol",
+        "wildcardsymbol", -- "plussymbol", "minussymbol",
         --
         "normalhyphenationcode", "automatichyphenationcode", "explicithyphenationcode", "syllablehyphenationcode", "uppercasehyphenationcode",
         "collapsehyphenationcode", "compoundhyphenationcode", "strictstarthyphenationcode", "strictendhyphenationcode",
@@ -254,6 +263,9 @@ return {
         "operatoritaliccorrectionclassoptioncode", "shortinlineclassoptioncode",
         "pushnestingclassoptioncode", "popnestingclassoptioncode", "obeynestingclassoptioncode",
         --
+        "checkheightinsertoptioncode",
+        "pageinsertcategorycode",
+        --
         "noitaliccorrectionglyphoptioncode", "nozeroitaliccorrectionglyphoptioncode",
         "noexpansionglyphoptioncode", "noprotrusionglyphoptioncode",
         "noleftkernglyphoptioncode",  "norightkernglyphoptioncode",
@@ -267,10 +279,14 @@ return {
         "repeatspecificationoptioncode", "doublespecificationoptioncode", "largestspecificationoptioncode",
         "presetsspecificationoptioncode", "integerspecificationoptioncode", "finalspecificationoptioncode",
         "defaultspecificationoptioncode", "ignorespecificationoptioncode", "rotatespecificationoptioncode",
+        "constantspecificationoptioncode",
         --
-     -- "noitaliccorrectionmathoptioncode", "noleftpairkernmathoptioncode", "norightpairkernmathoptioncode",
-     -- "autodiscretionarymathoptioncode", "fulldiscretionarymathoptioncode",
-     -- "ignoredcharactermathoptioncode", "islargeoperatormathoptioncode", "hasitalicshapemathoptioncode",
+        "shortmathoptioncode", "orphanedmathoptioncode", "displaymathoptioncode", "crampedmathoptioncode",
+        "nosnappingmathoptioncode", "textmathoptioncode",
+        --
+     -- "noitaliccorrectionkerneloptioncode", "noleftpairkernkerneloptioncode", "norightpairkernkerneloptioncode",
+     -- "autodiscretionarykerneloptioncode", "fulldiscretionarykerneloptioncode",
+     -- "ignoredcharacterkerneloptioncode", "islargeoperatorkerneloptioncode", "hasitalicshapekerneloptioncode",
         --
         "nokerningcode", "noligaturingcode", "noitalicscode",
         --
@@ -300,6 +316,8 @@ return {
         "defaultgriddisplaywidowpenalty", "defaultgridwidowpenalty", "defaultgridclubpenalty", "defaultgridbrokenpenalty",
         --
         "luametatexverboseversion", "luametatexfunctionality",
+        --
+        "currentverbosemathstyle",
     },
     ["helpers"] = {
         --
@@ -327,7 +345,7 @@ return {
         --
         "newcount", "newdimen", "newskip", "newmuskip", "newbox", "newtoks", "newread", "newwrite", "newmarks", "newinsert", "newattribute", "newif", "newfloat", "newmvl",
         "newlanguage", "newfamily", "newfam", "newhelp", -- not used
-        "newuserunit",
+        "newuserunit", "userunitcode",
         --
         "newinteger", "newdimension", "newgluespec", "newmugluespec", "newposit",
         "aliasinteger", "aliasdimension", "aliasposit",
@@ -401,6 +419,8 @@ return {
         "scratchbox", "globalscratchbox", "privatescratchbox",
         "scratchmacro", "scratchmacroone", "scratchmacrotwo",
         --
+        "ignoredtoks",
+        --
         "scratchconditiontrue", "scratchconditionfalse", "ifscratchcondition",
         "scratchconditiononetrue", "scratchconditiononefalse", "ifscratchconditionone",
         "scratchconditiontwotrue", "scratchconditiontwofalse", "ifscratchconditiontwo",
@@ -447,6 +467,8 @@ return {
         --
         "scratchleftskip", "scratchrightskip", "scratchtopskip", "scratchbottomskip",
         --
+        "startimage", "stopimage",
+        --
         "doif", "doifnot", "doifelse",
         "firstinset",
         "doifinset", "doifnotinset",
@@ -479,7 +501,8 @@ return {
         --
         "quitcondition", "truecondition", "falsecondition",
         --
-        "tracingall", "tracingnone", "loggingall", "tracingcatcodes",
+        "tracingall", "tracingnone", "loggingall", "tracingcatcodes", "tracingprocess", "tracingtypesetting",
+
         "showluatokens",
         --
         "aliasmacro",
@@ -521,12 +544,14 @@ return {
         --
         "getdummyparameters", "dummyparameter", "directdummyparameter", "setdummyparameter", "letdummyparameter",
         "setexpandeddummyparameter", "resetdummyparameter",
-        "usedummystyleandcolor", "usedummystyleparameter", "usedummycolorparameter",
+        "usedummystyleandcolor", "usedummystyleparameter", "usedummycolorparameter", "usedummylanguageparameter",
         --
         "processcommalist", "processcommacommand", "quitcommalist", "quitprevcommalist",
         "processaction", "processallactions", "processfirstactioninset", "processallactionsinset",
         --
-        "unexpanded", "expanded", "startexpanded", "stopexpanded", "protect", "unprotect",
+        "unexpanded",
+     -- "expanded",
+        "startexpanded", "stopexpanded", "protect", "unprotect",
         --
         "firstofoneargument",
         "firstoftwoarguments", "secondoftwoarguments",
@@ -574,7 +599,7 @@ return {
         "offinterlineskip", "oninterlineskip", "nointerlineskip",
         --
         "strut", "halfstrut", "quarterstrut", "depthstrut", "halflinestrut", "noheightstrut", "setstrut", "strutbox", "strutht", "strutdp", "strutwd", "struthtdp", "strutgap", "begstrut", "endstrut", "lineheight",
-        "leftboundary", "rightboundary", "signalcharacter",
+        "leftboundary", "rightboundary", "signalcharacter", "signalglyph",
         "ascender", "descender", "capheight",
         --
         "aligncontentleft", "aligncontentmiddle", "aligncontentright",
@@ -675,8 +700,6 @@ return {
         "updateparagraphproperties", "updateparagraphpenalties", "updateparagraphdemerits", "updateparagraphshapes", "updateparagraphlines",
         "updateparagraphpasses",
         --
-        "lastlinewidth",
-        --
         "assumelongusagecs",
         --
         "righttolefthbox", "lefttorighthbox", "righttoleftvbox", "lefttorightvbox", "righttoleftvtop", "lefttorightvtop",
@@ -746,7 +769,7 @@ return {
         "parcontextcodestring",
         --
         "newlocalcount", "newlocaldimen", "newlocalskip", "newlocalmuskip", "newlocaltoks", "newlocalbox",
-        "newlocalwrite", "newlocalread",
+        "newlocalwrite", "newlocalread", "newlocalfloat",
         "setnewlocalcount", "setnewlocaldimen", "setnewlocalskip", "setnewlocalmuskip", "setnewlocaltoks", "setnewlocalbox",
         --
         "ifexpression",
@@ -792,5 +815,11 @@ return {
         "nohpenalties", "novpenalties",
         --
         "toddlerpenalty", "orphanpenalty",
+        --
+        "digitspace",
+        --
+        "inhibitprimitive",
+        --
+        "thespecification",
     }
 }
